@@ -1,4 +1,3 @@
-
 import os.path as osp
 
 import torch
@@ -7,7 +6,7 @@ import torchvision
 HERE = osp.dirname(osp.abspath(__file__))
 ASSETS = osp.dirname(osp.dirname(HERE))
 
-model = torchvision.models.detection.fasterrcnn_resnet50_fpn(pretrained=False)
+model = torchvision.models.detection.fasterrcnn_resnet50_fpn(weights=None, weights_backbone=None)
 model.eval()
 
 traced_model = torch.jit.script(model)
